Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6691)

Unified Diff: chrome/browser/ui/views/frame/opaque_browser_frame_view_layout.h

Issue 1685763004: Fix various issues with popup/app window layout/drawing. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@cleanup
Patch Set: Fix unittest Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/opaque_browser_frame_view_layout.h
diff --git a/chrome/browser/ui/views/frame/opaque_browser_frame_view_layout.h b/chrome/browser/ui/views/frame/opaque_browser_frame_view_layout.h
index 8dc755ff678b762e4b51b63df4a4ebd6d2f6787f..e4e9c393cdc8dd32c277457f2099262f4be93d01 100644
--- a/chrome/browser/ui/views/frame/opaque_browser_frame_view_layout.h
+++ b/chrome/browser/ui/views/frame/opaque_browser_frame_view_layout.h
@@ -35,6 +35,7 @@ class OpaqueBrowserFrameViewLayout : public views::LayoutManager {
static const int kIconLeftSpacing;
static const int kIconTitleSpacing;
static const int kCaptionSpacing;
+ static const int kCaptionButtonBottomPadding;
static const int kNewTabCaptionCondensedSpacing;
explicit OpaqueBrowserFrameViewLayout(
@@ -83,10 +84,10 @@ class OpaqueBrowserFrameViewLayout : public views::LayoutManager {
// acts as if the window is restored regardless of the real mode.
int CaptionButtonY(bool restored) const;
// Returns the thickness of the 3D edge along the bottom of the titlebar. If
// |restored| is true, acts as if the window is restored regardless of the
// real mode.
- int TitlebarBottomThickness(bool restored) const;
+ int TitlebarTopThickness(bool restored) const;
// Returns the bounds of the titlebar icon (or where the icon would be if
// there was one).
@@ -83,10 +84,10 @@ class OpaqueBrowserFrameViewLayout : public views::LayoutManager {
// acts as if the window is restored regardless of the real mode.
int CaptionButtonY(bool restored) const;
- // Returns the thickness of the 3D edge along the bottom of the titlebar. If
+ // Returns the thickness of the 3D edge along the top of the titlebar. If
// |restored| is true, acts as if the window is restored regardless of the
// real mode.

Powered by Google App Engine
This is Rietveld 408576698